/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.jmx.artifact;

import org.ow2.petals.admin.api.artifact.Component;
import org.ow2.petals.admin.api.artifact.ServiceAssembly;
import org.ow2.petals.admin.api.artifact.SharedLibrary;
import org.ow2.petals.admin.api.artifact.lifecycle.ArtifactLifecycleFactory;
import org.ow2.petals.admin.api.artifact.lifecycle.ComponentLifecycle;
import org.ow2.petals.admin.api.artifact.lifecycle.ServiceAssemblyLifecycle;
import org.ow2.petals.admin.api.artifact.lifecycle.SharedLibraryLifecycle;
import org.ow2.petals.admin.api.conf.ArtifactUrlRewriter;
import org.ow2.petals.admin.jmx.JMXPetalsAdministration;

/**
 * 
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public final class JMXArtifactLifecycleFactory extends ArtifactLifecycleFactory {

    private final JMXPetalsAdministration admin;

    private final ArtifactUrlRewriter artifactUrlRewriter;

    public JMXArtifactLifecycleFactory(final JMXPetalsAdministration admin,
            final ArtifactUrlRewriter artifactUrlRewriter) {
        this.admin = admin;
        this.artifactUrlRewriter = artifactUrlRewriter;
    }

    @Override
    public ComponentLifecycle createComponentLifecycle(Component c) {
        return new JMXComponentLifecycle(c, admin, artifactUrlRewriter);
    }

    @Override
    public ServiceAssemblyLifecycle createServiceAssemblyLifecycle(ServiceAssembly sa) {
        return new JMXServiceAssemblyLifecycle(sa, admin, artifactUrlRewriter);
    }

    @Override
    public SharedLibraryLifecycle createSharedLibraryLifecycle(SharedLibrary sl) {
        return new JMXSharedLibraryLifecycle(sl, admin, artifactUrlRewriter);
    }
}
