/**
 * Copyright (c) 2016-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.jmx;

import org.junit.Rule;
import org.junit.Test;
import org.ow2.petals.admin.api.PetalsAdministration;
import org.ow2.petals.admin.api.PetalsAdministrationFactory;
import org.ow2.petals.admin.api.exception.ContainerAdministrationException;
import org.ow2.petals.admin.api.exception.DuplicatedServiceException;
import org.ow2.petals.admin.api.exception.MissingServiceException;
import org.ow2.petals.admin.api.exception.NoConnectionException;
import org.ow2.petals.jmx.api.api.exception.NotRemoteJMXClientException;
import org.ow2.petals.jmx.api.mock.junit.PetalsJmxApiJunitRule;

public class JMXPetalsAdministrationTest {

    @Rule
    final public PetalsJmxApiJunitRule jmxApiContainer0 = new PetalsJmxApiJunitRule();

    /**
     * <p>
     * Check the {@link JMXPetalsAdministration#connect(String, int, String, String)} when the JMX connection failed.
     * </p>
     * <p>
     * Expected results: The exception {@link ContainerAdministrationException} occurs.
     * </p>
     */
    @Test(expected = ContainerAdministrationException.class)
    public void connectUnsuccessfully() throws DuplicatedServiceException, MissingServiceException,
            NotRemoteJMXClientException, ContainerAdministrationException {
        final PetalsAdministration adminApi = PetalsAdministrationFactory.getInstance().newPetalsAdministrationAPI();
        adminApi.connect("unknown-host", this.jmxApiContainer0.getPort(), this.jmxApiContainer0.getUsername(),
                "petals");
    }

    /**
     * <p>
     * Check the {@link JMXPetalsAdministration#connect(String, int, String, String)} to established successfully a
     * connection before to disconnect it with {@link JMXPetalsAdministration#disconnect()}.
     * </p>
     * <p>
     * Expected results: No error occurs.
     * </p>
     */
    @Test
    public void disconnectAfterConnection() throws DuplicatedServiceException, MissingServiceException,
            ContainerAdministrationException, NotRemoteJMXClientException {
        final PetalsAdministration adminApi = PetalsAdministrationFactory.getInstance().newPetalsAdministrationAPI();
        adminApi.connect("localhost", this.jmxApiContainer0.getPort(), this.jmxApiContainer0.getUsername(), "petals");
        adminApi.disconnect();
    }

    /**
     * <p>
     * Check the {@link JMXPetalsAdministration#disconnect()} when no JMX connection is established.
     * </p>
     * <p>
     * Expected results: The exception {@link NoConnectionException} occurs.
     * </p>
     */
    @Test(expected = NoConnectionException.class)
    public void disconnectWithoutConnection()
            throws DuplicatedServiceException, MissingServiceException, ContainerAdministrationException {
        final PetalsAdministration adminApi = PetalsAdministrationFactory.getInstance().newPetalsAdministrationAPI();
        adminApi.disconnect();
    }
}
